@@ -114,7 +114,7 @@ class RESTRouteVersionMethod:
 
     @classmethod
     def _exception_to_manageable_error(cls, error):
-        return type(error.__class__.__name__, (exceptions.Error, error,), {})
+        return type(error.__class__.__name__, (error.__class__, exceptions.Error,), {})
 
     def __init__(
             self,
@@ -199,14 +199,14 @@ class RESTRouteVersionMethod:
                     if cache_response['ETag'] == request.headers['If-None-Match']:
                         response = HttpResponseNotModified()
 
-                except KeyError: # pylint: disable=except-pass
+                except KeyError:
                     pass
 
                 try:
                     if cache_response['Last-Modified'] == request.headers['If-Modified-Since']:
                         response = HttpResponseNotModified()
 
-                except KeyError: # pylint: disable=except-pass
+                except KeyError:
                     pass
 
         if not response:
@@ -225,13 +225,13 @@ class RESTRouteVersionMethod:
                 try:
                     response['ETag'] = cache_response['ETag']
 
-                except KeyError: # pylint: disable=except-pass
+                except KeyError:
                     pass
 
                 try:
                     response['Last-Modified'] = cache_response['Last-Modified']
 
-                except KeyError: # pylint: disable=except-pass
+                except KeyError:
                     pass
 
         if self.response_modifier:
